# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe._request_options import RequestOptions
from typing import List, Union
from typing_extensions import Literal, NotRequired, TypedDict


class RegistrationCreateParams(RequestOptions):
    active_from: Union[Literal["now"], int]
    """
    Time at which the Tax Registration becomes active. It can be either `now` to indicate the current time, or a future timestamp measured in seconds since the Unix epoch.
    """
    country: str
    """
    Two-letter country code ([ISO 3166-1 alpha-2](https://en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
    """
    country_options: "RegistrationCreateParamsCountryOptions"
    """
    Specific options for a registration in the specified `country`.
    """
    expand: NotRequired[List[str]]
    """
    Specifies which fields in the response should be expanded.
    """
    expires_at: NotRequired[int]
    """
    If set, the Tax Registration stops being active at this time. If not set, the Tax Registration will be active indefinitely. Timestamp measured in seconds since the Unix epoch.
    """


_RegistrationCreateParamsCountryOptionsBase = TypedDict(
    "RegistrationCreateParamsCountryOptions",
    {
        "in": NotRequired["RegistrationCreateParamsCountryOptionsIn"],
        "is": NotRequired["RegistrationCreateParamsCountryOptionsIs"],
    },
)


class RegistrationCreateParamsCountryOptions(
    _RegistrationCreateParamsCountryOptionsBase,
):
    ae: NotRequired["RegistrationCreateParamsCountryOptionsAe"]
    """
    Options for the registration in AE.
    """
    al: NotRequired["RegistrationCreateParamsCountryOptionsAl"]
    """
    Options for the registration in AL.
    """
    am: NotRequired["RegistrationCreateParamsCountryOptionsAm"]
    """
    Options for the registration in AM.
    """
    ao: NotRequired["RegistrationCreateParamsCountryOptionsAo"]
    """
    Options for the registration in AO.
    """
    at: NotRequired["RegistrationCreateParamsCountryOptionsAt"]
    """
    Options for the registration in AT.
    """
    au: NotRequired["RegistrationCreateParamsCountryOptionsAu"]
    """
    Options for the registration in AU.
    """
    aw: NotRequired["RegistrationCreateParamsCountryOptionsAw"]
    """
    Options for the registration in AW.
    """
    az: NotRequired["RegistrationCreateParamsCountryOptionsAz"]
    """
    Options for the registration in AZ.
    """
    ba: NotRequired["RegistrationCreateParamsCountryOptionsBa"]
    """
    Options for the registration in BA.
    """
    bb: NotRequired["RegistrationCreateParamsCountryOptionsBb"]
    """
    Options for the registration in BB.
    """
    bd: NotRequired["RegistrationCreateParamsCountryOptionsBd"]
    """
    Options for the registration in BD.
    """
    be: NotRequired["RegistrationCreateParamsCountryOptionsBe"]
    """
    Options for the registration in BE.
    """
    bf: NotRequired["RegistrationCreateParamsCountryOptionsBf"]
    """
    Options for the registration in BF.
    """
    bg: NotRequired["RegistrationCreateParamsCountryOptionsBg"]
    """
    Options for the registration in BG.
    """
    bh: NotRequired["RegistrationCreateParamsCountryOptionsBh"]
    """
    Options for the registration in BH.
    """
    bj: NotRequired["RegistrationCreateParamsCountryOptionsBj"]
    """
    Options for the registration in BJ.
    """
    bs: NotRequired["RegistrationCreateParamsCountryOptionsBs"]
    """
    Options for the registration in BS.
    """
    by: NotRequired["RegistrationCreateParamsCountryOptionsBy"]
    """
    Options for the registration in BY.
    """
    ca: NotRequired["RegistrationCreateParamsCountryOptionsCa"]
    """
    Options for the registration in CA.
    """
    cd: NotRequired["RegistrationCreateParamsCountryOptionsCd"]
    """
    Options for the registration in CD.
    """
    ch: NotRequired["RegistrationCreateParamsCountryOptionsCh"]
    """
    Options for the registration in CH.
    """
    cl: NotRequired["RegistrationCreateParamsCountryOptionsCl"]
    """
    Options for the registration in CL.
    """
    cm: NotRequired["RegistrationCreateParamsCountryOptionsCm"]
    """
    Options for the registration in CM.
    """
    co: NotRequired["RegistrationCreateParamsCountryOptionsCo"]
    """
    Options for the registration in CO.
    """
    cr: NotRequired["RegistrationCreateParamsCountryOptionsCr"]
    """
    Options for the registration in CR.
    """
    cv: NotRequired["RegistrationCreateParamsCountryOptionsCv"]
    """
    Options for the registration in CV.
    """
    cy: NotRequired["RegistrationCreateParamsCountryOptionsCy"]
    """
    Options for the registration in CY.
    """
    cz: NotRequired["RegistrationCreateParamsCountryOptionsCz"]
    """
    Options for the registration in CZ.
    """
    de: NotRequired["RegistrationCreateParamsCountryOptionsDe"]
    """
    Options for the registration in DE.
    """
    dk: NotRequired["RegistrationCreateParamsCountryOptionsDk"]
    """
    Options for the registration in DK.
    """
    ec: NotRequired["RegistrationCreateParamsCountryOptionsEc"]
    """
    Options for the registration in EC.
    """
    ee: NotRequired["RegistrationCreateParamsCountryOptionsEe"]
    """
    Options for the registration in EE.
    """
    eg: NotRequired["RegistrationCreateParamsCountryOptionsEg"]
    """
    Options for the registration in EG.
    """
    es: NotRequired["RegistrationCreateParamsCountryOptionsEs"]
    """
    Options for the registration in ES.
    """
    et: NotRequired["RegistrationCreateParamsCountryOptionsEt"]
    """
    Options for the registration in ET.
    """
    fi: NotRequired["RegistrationCreateParamsCountryOptionsFi"]
    """
    Options for the registration in FI.
    """
    fr: NotRequired["RegistrationCreateParamsCountryOptionsFr"]
    """
    Options for the registration in FR.
    """
    gb: NotRequired["RegistrationCreateParamsCountryOptionsGb"]
    """
    Options for the registration in GB.
    """
    ge: NotRequired["RegistrationCreateParamsCountryOptionsGe"]
    """
    Options for the registration in GE.
    """
    gn: NotRequired["RegistrationCreateParamsCountryOptionsGn"]
    """
    Options for the registration in GN.
    """
    gr: NotRequired["RegistrationCreateParamsCountryOptionsGr"]
    """
    Options for the registration in GR.
    """
    hr: NotRequired["RegistrationCreateParamsCountryOptionsHr"]
    """
    Options for the registration in HR.
    """
    hu: NotRequired["RegistrationCreateParamsCountryOptionsHu"]
    """
    Options for the registration in HU.
    """
    id: NotRequired["RegistrationCreateParamsCountryOptionsId"]
    """
    Options for the registration in ID.
    """
    ie: NotRequired["RegistrationCreateParamsCountryOptionsIe"]
    """
    Options for the registration in IE.
    """
    it: NotRequired["RegistrationCreateParamsCountryOptionsIt"]
    """
    Options for the registration in IT.
    """
    jp: NotRequired["RegistrationCreateParamsCountryOptionsJp"]
    """
    Options for the registration in JP.
    """
    ke: NotRequired["RegistrationCreateParamsCountryOptionsKe"]
    """
    Options for the registration in KE.
    """
    kg: NotRequired["RegistrationCreateParamsCountryOptionsKg"]
    """
    Options for the registration in KG.
    """
    kh: NotRequired["RegistrationCreateParamsCountryOptionsKh"]
    """
    Options for the registration in KH.
    """
    kr: NotRequired["RegistrationCreateParamsCountryOptionsKr"]
    """
    Options for the registration in KR.
    """
    kz: NotRequired["RegistrationCreateParamsCountryOptionsKz"]
    """
    Options for the registration in KZ.
    """
    la: NotRequired["RegistrationCreateParamsCountryOptionsLa"]
    """
    Options for the registration in LA.
    """
    lt: NotRequired["RegistrationCreateParamsCountryOptionsLt"]
    """
    Options for the registration in LT.
    """
    lu: NotRequired["RegistrationCreateParamsCountryOptionsLu"]
    """
    Options for the registration in LU.
    """
    lv: NotRequired["RegistrationCreateParamsCountryOptionsLv"]
    """
    Options for the registration in LV.
    """
    ma: NotRequired["RegistrationCreateParamsCountryOptionsMa"]
    """
    Options for the registration in MA.
    """
    md: NotRequired["RegistrationCreateParamsCountryOptionsMd"]
    """
    Options for the registration in MD.
    """
    me: NotRequired["RegistrationCreateParamsCountryOptionsMe"]
    """
    Options for the registration in ME.
    """
    mk: NotRequired["RegistrationCreateParamsCountryOptionsMk"]
    """
    Options for the registration in MK.
    """
    mr: NotRequired["RegistrationCreateParamsCountryOptionsMr"]
    """
    Options for the registration in MR.
    """
    mt: NotRequired["RegistrationCreateParamsCountryOptionsMt"]
    """
    Options for the registration in MT.
    """
    mx: NotRequired["RegistrationCreateParamsCountryOptionsMx"]
    """
    Options for the registration in MX.
    """
    my: NotRequired["RegistrationCreateParamsCountryOptionsMy"]
    """
    Options for the registration in MY.
    """
    ng: NotRequired["RegistrationCreateParamsCountryOptionsNg"]
    """
    Options for the registration in NG.
    """
    nl: NotRequired["RegistrationCreateParamsCountryOptionsNl"]
    """
    Options for the registration in NL.
    """
    no: NotRequired["RegistrationCreateParamsCountryOptionsNo"]
    """
    Options for the registration in NO.
    """
    np: NotRequired["RegistrationCreateParamsCountryOptionsNp"]
    """
    Options for the registration in NP.
    """
    nz: NotRequired["RegistrationCreateParamsCountryOptionsNz"]
    """
    Options for the registration in NZ.
    """
    om: NotRequired["RegistrationCreateParamsCountryOptionsOm"]
    """
    Options for the registration in OM.
    """
    pe: NotRequired["RegistrationCreateParamsCountryOptionsPe"]
    """
    Options for the registration in PE.
    """
    ph: NotRequired["RegistrationCreateParamsCountryOptionsPh"]
    """
    Options for the registration in PH.
    """
    pl: NotRequired["RegistrationCreateParamsCountryOptionsPl"]
    """
    Options for the registration in PL.
    """
    pt: NotRequired["RegistrationCreateParamsCountryOptionsPt"]
    """
    Options for the registration in PT.
    """
    ro: NotRequired["RegistrationCreateParamsCountryOptionsRo"]
    """
    Options for the registration in RO.
    """
    rs: NotRequired["RegistrationCreateParamsCountryOptionsRs"]
    """
    Options for the registration in RS.
    """
    ru: NotRequired["RegistrationCreateParamsCountryOptionsRu"]
    """
    Options for the registration in RU.
    """
    sa: NotRequired["RegistrationCreateParamsCountryOptionsSa"]
    """
    Options for the registration in SA.
    """
    se: NotRequired["RegistrationCreateParamsCountryOptionsSe"]
    """
    Options for the registration in SE.
    """
    sg: NotRequired["RegistrationCreateParamsCountryOptionsSg"]
    """
    Options for the registration in SG.
    """
    si: NotRequired["RegistrationCreateParamsCountryOptionsSi"]
    """
    Options for the registration in SI.
    """
    sk: NotRequired["RegistrationCreateParamsCountryOptionsSk"]
    """
    Options for the registration in SK.
    """
    sn: NotRequired["RegistrationCreateParamsCountryOptionsSn"]
    """
    Options for the registration in SN.
    """
    sr: NotRequired["RegistrationCreateParamsCountryOptionsSr"]
    """
    Options for the registration in SR.
    """
    th: NotRequired["RegistrationCreateParamsCountryOptionsTh"]
    """
    Options for the registration in TH.
    """
    tj: NotRequired["RegistrationCreateParamsCountryOptionsTj"]
    """
    Options for the registration in TJ.
    """
    tr: NotRequired["RegistrationCreateParamsCountryOptionsTr"]
    """
    Options for the registration in TR.
    """
    tw: NotRequired["RegistrationCreateParamsCountryOptionsTw"]
    """
    Options for the registration in TW.
    """
    tz: NotRequired["RegistrationCreateParamsCountryOptionsTz"]
    """
    Options for the registration in TZ.
    """
    ua: NotRequired["RegistrationCreateParamsCountryOptionsUa"]
    """
    Options for the registration in UA.
    """
    ug: NotRequired["RegistrationCreateParamsCountryOptionsUg"]
    """
    Options for the registration in UG.
    """
    us: NotRequired["RegistrationCreateParamsCountryOptionsUs"]
    """
    Options for the registration in US.
    """
    uy: NotRequired["RegistrationCreateParamsCountryOptionsUy"]
    """
    Options for the registration in UY.
    """
    uz: NotRequired["RegistrationCreateParamsCountryOptionsUz"]
    """
    Options for the registration in UZ.
    """
    vn: NotRequired["RegistrationCreateParamsCountryOptionsVn"]
    """
    Options for the registration in VN.
    """
    za: NotRequired["RegistrationCreateParamsCountryOptionsZa"]
    """
    Options for the registration in ZA.
    """
    zm: NotRequired["RegistrationCreateParamsCountryOptionsZm"]
    """
    Options for the registration in ZM.
    """
    zw: NotRequired["RegistrationCreateParamsCountryOptionsZw"]
    """
    Options for the registration in ZW.
    """


class RegistrationCreateParamsCountryOptionsAe(TypedDict):
    standard: NotRequired["RegistrationCreateParamsCountryOptionsAeStandard"]
    """
    Options for the standard registration.
    """
    type: Literal["standard"]
    """
    Type of registration to be created in `country`.
    """


class RegistrationCreateParamsCountryOptionsAeStandard(TypedDict):
    place_of_supply_scheme: NotRequired[Literal["inbound_goods", "standard"]]
    """
    Place of supply scheme used in an standard registration.
    """


class RegistrationCreateParamsCountryOptionsAl(TypedDict):
    standard: NotRequired["RegistrationCreateParamsCountryOptionsAlStandard"]
    """
    Options for the standard registration.
    """
    type: Literal["standard"]
    """
    Type of registration to be created in `country`.
    """


class RegistrationCreateParamsCountryOptionsAlStandard(TypedDict):
    place_of_supply_scheme: NotRequired[Literal["inbound_goods", "standard"]]
    """
    Place of supply scheme used in an standard registration.
    """


class RegistrationCreateParamsCountryOptionsAm(TypedDict):
    type: Literal["simplified"]
    """
    Type of registration to be created in `country`.
    """


class RegistrationCreateParamsCountryOptionsAo(TypedDict):
    standard: NotRequired["RegistrationCreateParamsCountryOptionsAoStandard"]
    """
    Options for the standard registration.
    """
    type: Literal["standard"]
    """
    Type of registration to be created in `country`.
    """


class RegistrationCreateParamsCountryOptionsAoStandard(TypedDict):
    place_of_supply_scheme: NotRequired[Literal["inbound_goods", "standard"]]
    """
    Place of supply scheme used in an standard registration.
    """


class RegistrationCreateParamsCountryOptionsAt(TypedDict):
    standard: NotRequired["RegistrationCreateParamsCountryOptionsAtStandard"]
    """
    Options for the standard registration.
    """
    type: Literal["ioss", "oss_non_union", "oss_union", "standard"]
    """
    Type of registration to be created in an EU country.
    """


class RegistrationCreateParamsCountryOptionsAtStandard(TypedDict):
    place_of_supply_scheme: Literal[
        "inbound_goods", "small_seller", "standard"
    ]
    """
    Place of supply scheme used in an EU standard registration.
    """


class RegistrationCreateParamsCountryOptionsAu(TypedDict):
    standard: NotRequired["RegistrationCreateParamsCountryOptionsAuStandard"]
    """
    Options for the standard registration.
    """
    type: Literal["standard"]
    """
    Type of registration to be created in `country`.
    """


class RegistrationCreateParamsCountryOptionsAuStandard(TypedDict):
    place_of_supply_scheme: NotRequired[Literal["inbound_goods", "standard"]]
    """
    Place of supply scheme used in an standard registration.
    """


class RegistrationCreateParamsCountryOptionsAw(TypedDict):
    standard: NotRequired["RegistrationCreateParamsCountryOptionsAwStandard"]
    """
    Options for the standard registration.
    """
    type: Literal["standard"]
    """
    Type of registration to be created in `country`.
    """


class RegistrationCreateParamsCountryOptionsAwStandard(TypedDict):
    place_of_supply_scheme: NotRequired[Literal["inbound_goods", "standard"]]
    """
    Place of supply scheme used in an standard registration.
    """


class RegistrationCreateParamsCountryOptionsAz(TypedDict):
    type: Literal["simplified"]
    """
    Type of registration to be created in `country`.
    """


class RegistrationCreateParamsCountryOptionsBa(TypedDict):
    standard: NotRequired["RegistrationCreateParamsCountryOptionsBaStandard"]
    """
    Options for the standard registration.
    """
    type: Literal["standard"]
    """
    Type of registration to be created in `country`.
    """


class RegistrationCreateParamsCountryOptionsBaStandard(TypedDict):
    place_of_supply_scheme: NotRequired[Literal["inbound_goods", "standard"]]
    """
    Place of supply scheme used in an standard registration.
    """


class RegistrationCreateParamsCountryOptionsBb(TypedDict):
    standard: NotRequired["RegistrationCreateParamsCountryOptionsBbStandard"]
    """
    Options for the standard registration.
    """
    type: Literal["standard"]
    """
    Type of registration to be created in `country`.
    """


class RegistrationCreateParamsCountryOptionsBbStandard(TypedDict):
    place_of_supply_scheme: NotRequired[Literal["inbound_goods", "standard"]]
    """
    Place of supply scheme used in an standard registration.
    """


class RegistrationCreateParamsCountryOptionsBd(TypedDict):
    standard: NotRequired["RegistrationCreateParamsCountryOptionsBdStandard"]
    """
    Options for the standard registration.
    """
    type: Literal["standard"]
    """
    Type of registration to be created in `country`.
    """


class RegistrationCreateParamsCountryOptionsBdStandard(TypedDict):
    place_of_supply_scheme: NotRequired[Literal["inbound_goods", "standard"]]
    """
    Place of supply scheme used in an standard registration.
    """


class RegistrationCreateParamsCountryOptionsBe(TypedDict):
    standard: NotRequired["RegistrationCreateParamsCountryOptionsBeStandard"]
    """
    Options for the standard registration.
    """
    type: Literal["ioss", "oss_non_union", "oss_union", "standard"]
    """
    Type of registration to be created in an EU country.
    """


class RegistrationCreateParamsCountryOptionsBeStandard(TypedDict):
    place_of_supply_scheme: Literal[
        "inbound_goods", "small_seller", "standard"
    ]
    """
    Place of supply scheme used in an EU standard registration.
    """


class RegistrationCreateParamsCountryOptionsBf(TypedDict):
    standard: NotRequired["RegistrationCreateParamsCountryOptionsBfStandard"]
    """
    Options for the standard registration.
    """
    type: Literal["standard"]
    """
    Type of registration to be created in `country`.
    """


class RegistrationCreateParamsCountryOptionsBfStandard(TypedDict):
    place_of_supply_scheme: NotRequired[Literal["inbound_goods", "standard"]]
    """
    Place of supply scheme used in an standard registration.
    """


class RegistrationCreateParamsCountryOptionsBg(TypedDict):
    standard: NotRequired["RegistrationCreateParamsCountryOptionsBgStandard"]
    """
    Options for the standard registration.
    """
    type: Literal["ioss", "oss_non_union", "oss_union", "standard"]
    """
    Type of registration to be created in an EU country.
    """


class RegistrationCreateParamsCountryOptionsBgStandard(TypedDict):
    place_of_supply_scheme: Literal[
        "inbound_goods", "small_seller", "standard"
    ]
    """
    Place of supply scheme used in an EU standard registration.
    """


class RegistrationCreateParamsCountryOptionsBh(TypedDict):
    standard: NotRequired["RegistrationCreateParamsCountryOptionsBhStandard"]
    """
    Options for the standard registration.
    """
    type: Literal["standard"]
    """
    Type of registration to be created in `country`.
    """


class RegistrationCreateParamsCountryOptionsBhStandard(TypedDict):
    place_of_supply_scheme: NotRequired[Literal["inbound_goods", "standard"]]
    """
    Place of supply scheme used in an standard registration.
    """


class RegistrationCreateParamsCountryOptionsBj(TypedDict):
    type: Literal["simplified"]
    """
    Type of registration to be created in `country`.
    """


class RegistrationCreateParamsCountryOptionsBs(TypedDict):
    standard: NotRequired["RegistrationCreateParamsCountryOptionsBsStandard"]
    """
    Options for the standard registration.
    """
    type: Literal["standard"]
    """
    Type of registration to be created in `country`.
    """


class RegistrationCreateParamsCountryOptionsBsStandard(TypedDict):
    place_of_supply_scheme: NotRequired[Literal["inbound_goods", "standard"]]
    """
    Place of supply scheme used in an standard registration.
    """


class RegistrationCreateParamsCountryOptionsBy(TypedDict):
    type: Literal["simplified"]
    """
    Type of registration to be created in `country`.
    """


class RegistrationCreateParamsCountryOptionsCa(TypedDict):
    province_standard: NotRequired[
        "RegistrationCreateParamsCountryOptionsCaProvinceStandard"
    ]
    """
    Options for the provincial tax registration.
    """
    type: Literal["province_standard", "simplified", "standard"]
    """
    Type of registration to be created in Canada.
    """


class RegistrationCreateParamsCountryOptionsCaProvinceStandard(TypedDict):
    province: str
    """
    Two-letter CA province code ([ISO 3166-2](https://en.wikipedia.org/wiki/ISO_3166-2)).
    """


class RegistrationCreateParamsCountryOptionsCd(TypedDict):
    standard: NotRequired["RegistrationCreateParamsCountryOptionsCdStandard"]
    """
    Options for the standard registration.
    """
    type: Literal["standard"]
    """
    Type of registration to be created in `country`.
    """


class RegistrationCreateParamsCountryOptionsCdStandard(TypedDict):
    place_of_supply_scheme: NotRequired[Literal["inbound_goods", "standard"]]
    """
    Place of supply scheme used in an standard registration.
    """


class RegistrationCreateParamsCountryOptionsCh(TypedDict):
    standard: NotRequired["RegistrationCreateParamsCountryOptionsChStandard"]
    """
    Options for the standard registration.
    """
    type: Literal["standard"]
    """
    Type of registration to be created in `country`.
    """


class RegistrationCreateParamsCountryOptionsChStandard(TypedDict):
    place_of_supply_scheme: NotRequired[Literal["inbound_goods", "standard"]]
    """
    Place of supply scheme used in an standard registration.
    """


class RegistrationCreateParamsCountryOptionsCl(TypedDict):
    type: Literal["simplified"]
    """
    Type of registration to be created in `country`.
    """


class RegistrationCreateParamsCountryOptionsCm(TypedDict):
    type: Literal["simplified"]
    """
    Type of registration to be created in `country`.
    """


class RegistrationCreateParamsCountryOptionsCo(TypedDict):
    type: Literal["simplified"]
    """
    Type of registration to be created in `country`.
    """


class RegistrationCreateParamsCountryOptionsCr(TypedDict):
    type: Literal["simplified"]
    """
    Type of registration to be created in `country`.
    """


class RegistrationCreateParamsCountryOptionsCv(TypedDict):
    type: Literal["simplified"]
    """
    Type of registration to be created in `country`.
    """


class RegistrationCreateParamsCountryOptionsCy(TypedDict):
    standard: NotRequired["RegistrationCreateParamsCountryOptionsCyStandard"]
    """
    Options for the standard registration.
    """
    type: Literal["ioss", "oss_non_union", "oss_union", "standard"]
    """
    Type of registration to be created in an EU country.
    """


class RegistrationCreateParamsCountryOptionsCyStandard(TypedDict):
    place_of_supply_scheme: Literal[
        "inbound_goods", "small_seller", "standard"
    ]
    """
    Place of supply scheme used in an EU standard registration.
    """


class RegistrationCreateParamsCountryOptionsCz(TypedDict):
    standard: NotRequired["RegistrationCreateParamsCountryOptionsCzStandard"]
    """
    Options for the standard registration.
    """
    type: Literal["ioss", "oss_non_union", "oss_union", "standard"]
    """
    Type of registration to be created in an EU country.
    """


class RegistrationCreateParamsCountryOptionsCzStandard(TypedDict):
    place_of_supply_scheme: Literal[
        "inbound_goods", "small_seller", "standard"
    ]
    """
    Place of supply scheme used in an EU standard registration.
    """


class RegistrationCreateParamsCountryOptionsDe(TypedDict):
    standard: NotRequired["RegistrationCreateParamsCountryOptionsDeStandard"]
    """
    Options for the standard registration.
    """
    type: Literal["ioss", "oss_non_union", "oss_union", "standard"]
    """
    Type of registration to be created in an EU country.
    """


class RegistrationCreateParamsCountryOptionsDeStandard(TypedDict):
    place_of_supply_scheme: Literal[
        "inbound_goods", "small_seller", "standard"
    ]
    """
    Place of supply scheme used in an EU standard registration.
    """


class RegistrationCreateParamsCountryOptionsDk(TypedDict):
    standard: NotRequired["RegistrationCreateParamsCountryOptionsDkStandard"]
    """
    Options for the standard registration.
    """
    type: Literal["ioss", "oss_non_union", "oss_union", "standard"]
    """
    Type of registration to be created in an EU country.
    """


class RegistrationCreateParamsCountryOptionsDkStandard(TypedDict):
    place_of_supply_scheme: Literal[
        "inbound_goods", "small_seller", "standard"
    ]
    """
    Place of supply scheme used in an EU standard registration.
    """


class RegistrationCreateParamsCountryOptionsEc(TypedDict):
    type: Literal["simplified"]
    """
    Type of registration to be created in `country`.
    """


class RegistrationCreateParamsCountryOptionsEe(TypedDict):
    standard: NotRequired["RegistrationCreateParamsCountryOptionsEeStandard"]
    """
    Options for the standard registration.
    """
    type: Literal["ioss", "oss_non_union", "oss_union", "standard"]
    """
    Type of registration to be created in an EU country.
    """


class RegistrationCreateParamsCountryOptionsEeStandard(TypedDict):
    place_of_supply_scheme: Literal[
        "inbound_goods", "small_seller", "standard"
    ]
    """
    Place of supply scheme used in an EU standard registration.
    """


class RegistrationCreateParamsCountryOptionsEg(TypedDict):
    type: Literal["simplified"]
    """
    Type of registration to be created in `country`.
    """


class RegistrationCreateParamsCountryOptionsEs(TypedDict):
    standard: NotRequired["RegistrationCreateParamsCountryOptionsEsStandard"]
    """
    Options for the standard registration.
    """
    type: Literal["ioss", "oss_non_union", "oss_union", "standard"]
    """
    Type of registration to be created in an EU country.
    """


class RegistrationCreateParamsCountryOptionsEsStandard(TypedDict):
    place_of_supply_scheme: Literal[
        "inbound_goods", "small_seller", "standard"
    ]
    """
    Place of supply scheme used in an EU standard registration.
    """


class RegistrationCreateParamsCountryOptionsEt(TypedDict):
    standard: NotRequired["RegistrationCreateParamsCountryOptionsEtStandard"]
    """
    Options for the standard registration.
    """
    type: Literal["standard"]
    """
    Type of registration to be created in `country`.
    """


class RegistrationCreateParamsCountryOptionsEtStandard(TypedDict):
    place_of_supply_scheme: NotRequired[Literal["inbound_goods", "standard"]]
    """
    Place of supply scheme used in an standard registration.
    """


class RegistrationCreateParamsCountryOptionsFi(TypedDict):
    standard: NotRequired["RegistrationCreateParamsCountryOptionsFiStandard"]
    """
    Options for the standard registration.
    """
    type: Literal["ioss", "oss_non_union", "oss_union", "standard"]
    """
    Type of registration to be created in an EU country.
    """


class RegistrationCreateParamsCountryOptionsFiStandard(TypedDict):
    place_of_supply_scheme: Literal[
        "inbound_goods", "small_seller", "standard"
    ]
    """
    Place of supply scheme used in an EU standard registration.
    """


class RegistrationCreateParamsCountryOptionsFr(TypedDict):
    standard: NotRequired["RegistrationCreateParamsCountryOptionsFrStandard"]
    """
    Options for the standard registration.
    """
    type: Literal["ioss", "oss_non_union", "oss_union", "standard"]
    """
    Type of registration to be created in an EU country.
    """


class RegistrationCreateParamsCountryOptionsFrStandard(TypedDict):
    place_of_supply_scheme: Literal[
        "inbound_goods", "small_seller", "standard"
    ]
    """
    Place of supply scheme used in an EU standard registration.
    """


class RegistrationCreateParamsCountryOptionsGb(TypedDict):
    standard: NotRequired["RegistrationCreateParamsCountryOptionsGbStandard"]
    """
    Options for the standard registration.
    """
    type: Literal["standard"]
    """
    Type of registration to be created in `country`.
    """


class RegistrationCreateParamsCountryOptionsGbStandard(TypedDict):
    place_of_supply_scheme: NotRequired[Literal["inbound_goods", "standard"]]
    """
    Place of supply scheme used in an standard registration.
    """


class RegistrationCreateParamsCountryOptionsGe(TypedDict):
    type: Literal["simplified"]
    """
    Type of registration to be created in `country`.
    """


class RegistrationCreateParamsCountryOptionsGn(TypedDict):
    standard: NotRequired["RegistrationCreateParamsCountryOptionsGnStandard"]
    """
    Options for the standard registration.
    """
    type: Literal["standard"]
    """
    Type of registration to be created in `country`.
    """


class RegistrationCreateParamsCountryOptionsGnStandard(TypedDict):
    place_of_supply_scheme: NotRequired[Literal["inbound_goods", "standard"]]
    """
    Place of supply scheme used in an standard registration.
    """


class RegistrationCreateParamsCountryOptionsGr(TypedDict):
    standard: NotRequired["RegistrationCreateParamsCountryOptionsGrStandard"]
    """
    Options for the standard registration.
    """
    type: Literal["ioss", "oss_non_union", "oss_union", "standard"]
    """
    Type of registration to be created in an EU country.
    """


class RegistrationCreateParamsCountryOptionsGrStandard(TypedDict):
    place_of_supply_scheme: Literal[
        "inbound_goods", "small_seller", "standard"
    ]
    """
    Place of supply scheme used in an EU standard registration.
    """


class RegistrationCreateParamsCountryOptionsHr(TypedDict):
    standard: NotRequired["RegistrationCreateParamsCountryOptionsHrStandard"]
    """
    Options for the standard registration.
    """
    type: Literal["ioss", "oss_non_union", "oss_union", "standard"]
    """
    Type of registration to be created in an EU country.
    """


class RegistrationCreateParamsCountryOptionsHrStandard(TypedDict):
    place_of_supply_scheme: Literal[
        "inbound_goods", "small_seller", "standard"
    ]
    """
    Place of supply scheme used in an EU standard registration.
    """


class RegistrationCreateParamsCountryOptionsHu(TypedDict):
    standard: NotRequired["RegistrationCreateParamsCountryOptionsHuStandard"]
    """
    Options for the standard registration.
    """
    type: Literal["ioss", "oss_non_union", "oss_union", "standard"]
    """
    Type of registration to be created in an EU country.
    """


class RegistrationCreateParamsCountryOptionsHuStandard(TypedDict):
    place_of_supply_scheme: Literal[
        "inbound_goods", "small_seller", "standard"
    ]
    """
    Place of supply scheme used in an EU standard registration.
    """


class RegistrationCreateParamsCountryOptionsId(TypedDict):
    type: Literal["simplified"]
    """
    Type of registration to be created in `country`.
    """


class RegistrationCreateParamsCountryOptionsIe(TypedDict):
    standard: NotRequired["RegistrationCreateParamsCountryOptionsIeStandard"]
    """
    Options for the standard registration.
    """
    type: Literal["ioss", "oss_non_union", "oss_union", "standard"]
    """
    Type of registration to be created in an EU country.
    """


class RegistrationCreateParamsCountryOptionsIeStandard(TypedDict):
    place_of_supply_scheme: Literal[
        "inbound_goods", "small_seller", "standard"
    ]
    """
    Place of supply scheme used in an EU standard registration.
    """


class RegistrationCreateParamsCountryOptionsIn(TypedDict):
    type: Literal["simplified"]
    """
    Type of registration to be created in `country`.
    """


class RegistrationCreateParamsCountryOptionsIs(TypedDict):
    standard: NotRequired["RegistrationCreateParamsCountryOptionsIsStandard"]
    """
    Options for the standard registration.
    """
    type: Literal["standard"]
    """
    Type of registration to be created in `country`.
    """


class RegistrationCreateParamsCountryOptionsIsStandard(TypedDict):
    place_of_supply_scheme: NotRequired[Literal["inbound_goods", "standard"]]
    """
    Place of supply scheme used in an standard registration.
    """


class RegistrationCreateParamsCountryOptionsIt(TypedDict):
    standard: NotRequired["RegistrationCreateParamsCountryOptionsItStandard"]
    """
    Options for the standard registration.
    """
    type: Literal["ioss", "oss_non_union", "oss_union", "standard"]
    """
    Type of registration to be created in an EU country.
    """


class RegistrationCreateParamsCountryOptionsItStandard(TypedDict):
    place_of_supply_scheme: Literal[
        "inbound_goods", "small_seller", "standard"
    ]
    """
    Place of supply scheme used in an EU standard registration.
    """


class RegistrationCreateParamsCountryOptionsJp(TypedDict):
    standard: NotRequired["RegistrationCreateParamsCountryOptionsJpStandard"]
    """
    Options for the standard registration.
    """
    type: Literal["standard"]
    """
    Type of registration to be created in `country`.
    """


class RegistrationCreateParamsCountryOptionsJpStandard(TypedDict):
    place_of_supply_scheme: NotRequired[Literal["inbound_goods", "standard"]]
    """
    Place of supply scheme used in an standard registration.
    """


class RegistrationCreateParamsCountryOptionsKe(TypedDict):
    type: Literal["simplified"]
    """
    Type of registration to be created in `country`.
    """


class RegistrationCreateParamsCountryOptionsKg(TypedDict):
    type: Literal["simplified"]
    """
    Type of registration to be created in `country`.
    """


class RegistrationCreateParamsCountryOptionsKh(TypedDict):
    type: Literal["simplified"]
    """
    Type of registration to be created in `country`.
    """


class RegistrationCreateParamsCountryOptionsKr(TypedDict):
    type: Literal["simplified"]
    """
    Type of registration to be created in `country`.
    """


class RegistrationCreateParamsCountryOptionsKz(TypedDict):
    type: Literal["simplified"]
    """
    Type of registration to be created in `country`.
    """


class RegistrationCreateParamsCountryOptionsLa(TypedDict):
    type: Literal["simplified"]
    """
    Type of registration to be created in `country`.
    """


class RegistrationCreateParamsCountryOptionsLt(TypedDict):
    standard: NotRequired["RegistrationCreateParamsCountryOptionsLtStandard"]
    """
    Options for the standard registration.
    """
    type: Literal["ioss", "oss_non_union", "oss_union", "standard"]
    """
    Type of registration to be created in an EU country.
    """


class RegistrationCreateParamsCountryOptionsLtStandard(TypedDict):
    place_of_supply_scheme: Literal[
        "inbound_goods", "small_seller", "standard"
    ]
    """
    Place of supply scheme used in an EU standard registration.
    """


class RegistrationCreateParamsCountryOptionsLu(TypedDict):
    standard: NotRequired["RegistrationCreateParamsCountryOptionsLuStandard"]
    """
    Options for the standard registration.
    """
    type: Literal["ioss", "oss_non_union", "oss_union", "standard"]
    """
    Type of registration to be created in an EU country.
    """


class RegistrationCreateParamsCountryOptionsLuStandard(TypedDict):
    place_of_supply_scheme: Literal[
        "inbound_goods", "small_seller", "standard"
    ]
    """
    Place of supply scheme used in an EU standard registration.
    """


class RegistrationCreateParamsCountryOptionsLv(TypedDict):
    standard: NotRequired["RegistrationCreateParamsCountryOptionsLvStandard"]
    """
    Options for the standard registration.
    """
    type: Literal["ioss", "oss_non_union", "oss_union", "standard"]
    """
    Type of registration to be created in an EU country.
    """


class RegistrationCreateParamsCountryOptionsLvStandard(TypedDict):
    place_of_supply_scheme: Literal[
        "inbound_goods", "small_seller", "standard"
    ]
    """
    Place of supply scheme used in an EU standard registration.
    """


class RegistrationCreateParamsCountryOptionsMa(TypedDict):
    type: Literal["simplified"]
    """
    Type of registration to be created in `country`.
    """


class RegistrationCreateParamsCountryOptionsMd(TypedDict):
    type: Literal["simplified"]
    """
    Type of registration to be created in `country`.
    """


class RegistrationCreateParamsCountryOptionsMe(TypedDict):
    standard: NotRequired["RegistrationCreateParamsCountryOptionsMeStandard"]
    """
    Options for the standard registration.
    """
    type: Literal["standard"]
    """
    Type of registration to be created in `country`.
    """


class RegistrationCreateParamsCountryOptionsMeStandard(TypedDict):
    place_of_supply_scheme: NotRequired[Literal["inbound_goods", "standard"]]
    """
    Place of supply scheme used in an standard registration.
    """


class RegistrationCreateParamsCountryOptionsMk(TypedDict):
    standard: NotRequired["RegistrationCreateParamsCountryOptionsMkStandard"]
    """
    Options for the standard registration.
    """
    type: Literal["standard"]
    """
    Type of registration to be created in `country`.
    """


class RegistrationCreateParamsCountryOptionsMkStandard(TypedDict):
    place_of_supply_scheme: NotRequired[Literal["inbound_goods", "standard"]]
    """
    Place of supply scheme used in an standard registration.
    """


class RegistrationCreateParamsCountryOptionsMr(TypedDict):
    standard: NotRequired["RegistrationCreateParamsCountryOptionsMrStandard"]
    """
    Options for the standard registration.
    """
    type: Literal["standard"]
    """
    Type of registration to be created in `country`.
    """


class RegistrationCreateParamsCountryOptionsMrStandard(TypedDict):
    place_of_supply_scheme: NotRequired[Literal["inbound_goods", "standard"]]
    """
    Place of supply scheme used in an standard registration.
    """


class RegistrationCreateParamsCountryOptionsMt(TypedDict):
    standard: NotRequired["RegistrationCreateParamsCountryOptionsMtStandard"]
    """
    Options for the standard registration.
    """
    type: Literal["ioss", "oss_non_union", "oss_union", "standard"]
    """
    Type of registration to be created in an EU country.
    """


class RegistrationCreateParamsCountryOptionsMtStandard(TypedDict):
    place_of_supply_scheme: Literal[
        "inbound_goods", "small_seller", "standard"
    ]
    """
    Place of supply scheme used in an EU standard registration.
    """


class RegistrationCreateParamsCountryOptionsMx(TypedDict):
    type: Literal["simplified"]
    """
    Type of registration to be created in `country`.
    """


class RegistrationCreateParamsCountryOptionsMy(TypedDict):
    type: Literal["simplified"]
    """
    Type of registration to be created in `country`.
    """


class RegistrationCreateParamsCountryOptionsNg(TypedDict):
    type: Literal["simplified"]
    """
    Type of registration to be created in `country`.
    """


class RegistrationCreateParamsCountryOptionsNl(TypedDict):
    standard: NotRequired["RegistrationCreateParamsCountryOptionsNlStandard"]
    """
    Options for the standard registration.
    """
    type: Literal["ioss", "oss_non_union", "oss_union", "standard"]
    """
    Type of registration to be created in an EU country.
    """


class RegistrationCreateParamsCountryOptionsNlStandard(TypedDict):
    place_of_supply_scheme: Literal[
        "inbound_goods", "small_seller", "standard"
    ]
    """
    Place of supply scheme used in an EU standard registration.
    """


class RegistrationCreateParamsCountryOptionsNo(TypedDict):
    standard: NotRequired["RegistrationCreateParamsCountryOptionsNoStandard"]
    """
    Options for the standard registration.
    """
    type: Literal["standard"]
    """
    Type of registration to be created in `country`.
    """


class RegistrationCreateParamsCountryOptionsNoStandard(TypedDict):
    place_of_supply_scheme: NotRequired[Literal["inbound_goods", "standard"]]
    """
    Place of supply scheme used in an standard registration.
    """


class RegistrationCreateParamsCountryOptionsNp(TypedDict):
    type: Literal["simplified"]
    """
    Type of registration to be created in `country`.
    """


class RegistrationCreateParamsCountryOptionsNz(TypedDict):
    standard: NotRequired["RegistrationCreateParamsCountryOptionsNzStandard"]
    """
    Options for the standard registration.
    """
    type: Literal["standard"]
    """
    Type of registration to be created in `country`.
    """


class RegistrationCreateParamsCountryOptionsNzStandard(TypedDict):
    place_of_supply_scheme: NotRequired[Literal["inbound_goods", "standard"]]
    """
    Place of supply scheme used in an standard registration.
    """


class RegistrationCreateParamsCountryOptionsOm(TypedDict):
    standard: NotRequired["RegistrationCreateParamsCountryOptionsOmStandard"]
    """
    Options for the standard registration.
    """
    type: Literal["standard"]
    """
    Type of registration to be created in `country`.
    """


class RegistrationCreateParamsCountryOptionsOmStandard(TypedDict):
    place_of_supply_scheme: NotRequired[Literal["inbound_goods", "standard"]]
    """
    Place of supply scheme used in an standard registration.
    """


class RegistrationCreateParamsCountryOptionsPe(TypedDict):
    type: Literal["simplified"]
    """
    Type of registration to be created in `country`.
    """


class RegistrationCreateParamsCountryOptionsPh(TypedDict):
    type: Literal["simplified"]
    """
    Type of registration to be created in `country`.
    """


class RegistrationCreateParamsCountryOptionsPl(TypedDict):
    standard: NotRequired["RegistrationCreateParamsCountryOptionsPlStandard"]
    """
    Options for the standard registration.
    """
    type: Literal["ioss", "oss_non_union", "oss_union", "standard"]
    """
    Type of registration to be created in an EU country.
    """


class RegistrationCreateParamsCountryOptionsPlStandard(TypedDict):
    place_of_supply_scheme: Literal[
        "inbound_goods", "small_seller", "standard"
    ]
    """
    Place of supply scheme used in an EU standard registration.
    """


class RegistrationCreateParamsCountryOptionsPt(TypedDict):
    standard: NotRequired["RegistrationCreateParamsCountryOptionsPtStandard"]
    """
    Options for the standard registration.
    """
    type: Literal["ioss", "oss_non_union", "oss_union", "standard"]
    """
    Type of registration to be created in an EU country.
    """


class RegistrationCreateParamsCountryOptionsPtStandard(TypedDict):
    place_of_supply_scheme: Literal[
        "inbound_goods", "small_seller", "standard"
    ]
    """
    Place of supply scheme used in an EU standard registration.
    """


class RegistrationCreateParamsCountryOptionsRo(TypedDict):
    standard: NotRequired["RegistrationCreateParamsCountryOptionsRoStandard"]
    """
    Options for the standard registration.
    """
    type: Literal["ioss", "oss_non_union", "oss_union", "standard"]
    """
    Type of registration to be created in an EU country.
    """


class RegistrationCreateParamsCountryOptionsRoStandard(TypedDict):
    place_of_supply_scheme: Literal[
        "inbound_goods", "small_seller", "standard"
    ]
    """
    Place of supply scheme used in an EU standard registration.
    """


class RegistrationCreateParamsCountryOptionsRs(TypedDict):
    standard: NotRequired["RegistrationCreateParamsCountryOptionsRsStandard"]
    """
    Options for the standard registration.
    """
    type: Literal["standard"]
    """
    Type of registration to be created in `country`.
    """


class RegistrationCreateParamsCountryOptionsRsStandard(TypedDict):
    place_of_supply_scheme: NotRequired[Literal["inbound_goods", "standard"]]
    """
    Place of supply scheme used in an standard registration.
    """


class RegistrationCreateParamsCountryOptionsRu(TypedDict):
    type: Literal["simplified"]
    """
    Type of registration to be created in `country`.
    """


class RegistrationCreateParamsCountryOptionsSa(TypedDict):
    type: Literal["simplified"]
    """
    Type of registration to be created in `country`.
    """


class RegistrationCreateParamsCountryOptionsSe(TypedDict):
    standard: NotRequired["RegistrationCreateParamsCountryOptionsSeStandard"]
    """
    Options for the standard registration.
    """
    type: Literal["ioss", "oss_non_union", "oss_union", "standard"]
    """
    Type of registration to be created in an EU country.
    """


class RegistrationCreateParamsCountryOptionsSeStandard(TypedDict):
    place_of_supply_scheme: Literal[
        "inbound_goods", "small_seller", "standard"
    ]
    """
    Place of supply scheme used in an EU standard registration.
    """


class RegistrationCreateParamsCountryOptionsSg(TypedDict):
    standard: NotRequired["RegistrationCreateParamsCountryOptionsSgStandard"]
    """
    Options for the standard registration.
    """
    type: Literal["standard"]
    """
    Type of registration to be created in `country`.
    """


class RegistrationCreateParamsCountryOptionsSgStandard(TypedDict):
    place_of_supply_scheme: NotRequired[Literal["inbound_goods", "standard"]]
    """
    Place of supply scheme used in an standard registration.
    """


class RegistrationCreateParamsCountryOptionsSi(TypedDict):
    standard: NotRequired["RegistrationCreateParamsCountryOptionsSiStandard"]
    """
    Options for the standard registration.
    """
    type: Literal["ioss", "oss_non_union", "oss_union", "standard"]
    """
    Type of registration to be created in an EU country.
    """


class RegistrationCreateParamsCountryOptionsSiStandard(TypedDict):
    place_of_supply_scheme: Literal[
        "inbound_goods", "small_seller", "standard"
    ]
    """
    Place of supply scheme used in an EU standard registration.
    """


class RegistrationCreateParamsCountryOptionsSk(TypedDict):
    standard: NotRequired["RegistrationCreateParamsCountryOptionsSkStandard"]
    """
    Options for the standard registration.
    """
    type: Literal["ioss", "oss_non_union", "oss_union", "standard"]
    """
    Type of registration to be created in an EU country.
    """


class RegistrationCreateParamsCountryOptionsSkStandard(TypedDict):
    place_of_supply_scheme: Literal[
        "inbound_goods", "small_seller", "standard"
    ]
    """
    Place of supply scheme used in an EU standard registration.
    """


class RegistrationCreateParamsCountryOptionsSn(TypedDict):
    type: Literal["simplified"]
    """
    Type of registration to be created in `country`.
    """


class RegistrationCreateParamsCountryOptionsSr(TypedDict):
    standard: NotRequired["RegistrationCreateParamsCountryOptionsSrStandard"]
    """
    Options for the standard registration.
    """
    type: Literal["standard"]
    """
    Type of registration to be created in `country`.
    """


class RegistrationCreateParamsCountryOptionsSrStandard(TypedDict):
    place_of_supply_scheme: NotRequired[Literal["inbound_goods", "standard"]]
    """
    Place of supply scheme used in an standard registration.
    """


class RegistrationCreateParamsCountryOptionsTh(TypedDict):
    type: Literal["simplified"]
    """
    Type of registration to be created in `country`.
    """


class RegistrationCreateParamsCountryOptionsTj(TypedDict):
    type: Literal["simplified"]
    """
    Type of registration to be created in `country`.
    """


class RegistrationCreateParamsCountryOptionsTr(TypedDict):
    type: Literal["simplified"]
    """
    Type of registration to be created in `country`.
    """


class RegistrationCreateParamsCountryOptionsTw(TypedDict):
    type: Literal["simplified"]
    """
    Type of registration to be created in `country`.
    """


class RegistrationCreateParamsCountryOptionsTz(TypedDict):
    type: Literal["simplified"]
    """
    Type of registration to be created in `country`.
    """


class RegistrationCreateParamsCountryOptionsUa(TypedDict):
    type: Literal["simplified"]
    """
    Type of registration to be created in `country`.
    """


class RegistrationCreateParamsCountryOptionsUg(TypedDict):
    type: Literal["simplified"]
    """
    Type of registration to be created in `country`.
    """


class RegistrationCreateParamsCountryOptionsUs(TypedDict):
    local_amusement_tax: NotRequired[
        "RegistrationCreateParamsCountryOptionsUsLocalAmusementTax"
    ]
    """
    Options for the local amusement tax registration.
    """
    local_lease_tax: NotRequired[
        "RegistrationCreateParamsCountryOptionsUsLocalLeaseTax"
    ]
    """
    Options for the local lease tax registration.
    """
    state: str
    """
    Two-letter US state code ([ISO 3166-2](https://en.wikipedia.org/wiki/ISO_3166-2)).
    """
    state_sales_tax: NotRequired[
        "RegistrationCreateParamsCountryOptionsUsStateSalesTax"
    ]
    """
    Options for the state sales tax registration.
    """
    type: Literal[
        "local_amusement_tax",
        "local_lease_tax",
        "state_communications_tax",
        "state_retail_delivery_fee",
        "state_sales_tax",
    ]
    """
    Type of registration to be created in the US.
    """


class RegistrationCreateParamsCountryOptionsUsLocalAmusementTax(TypedDict):
    jurisdiction: str
    """
    A [FIPS code](https://www.census.gov/library/reference/code-lists/ansi.html) representing the local jurisdiction. Supported FIPS codes are: `14000` (Chicago), `02154` (Arlington Heights), `06613` (Bloomington), `10906` (Campton Hills), `21696` (East Dundee), `24582` (Evanston), `45421` (Lynwood), `48892` (Midlothian), `64343` (River Grove), and `68081` (Schiller Park).
    """


class RegistrationCreateParamsCountryOptionsUsLocalLeaseTax(TypedDict):
    jurisdiction: str
    """
    A [FIPS code](https://www.census.gov/library/reference/code-lists/ansi.html) representing the local jurisdiction. Supported FIPS codes are: `14000` (Chicago).
    """


class RegistrationCreateParamsCountryOptionsUsStateSalesTax(TypedDict):
    elections: List[
        "RegistrationCreateParamsCountryOptionsUsStateSalesTaxElection"
    ]
    """
    Elections for the state sales tax registration.
    """


class RegistrationCreateParamsCountryOptionsUsStateSalesTaxElection(TypedDict):
    jurisdiction: NotRequired[str]
    """
    A [FIPS code](https://www.census.gov/library/reference/code-lists/ansi.html) representing the local jurisdiction. Supported FIPS codes are: `003` (Allegheny County) and `60000` (Philadelphia City).
    """
    type: Literal[
        "local_use_tax", "simplified_sellers_use_tax", "single_local_use_tax"
    ]
    """
    The type of the election for the state sales tax registration.
    """


class RegistrationCreateParamsCountryOptionsUy(TypedDict):
    standard: NotRequired["RegistrationCreateParamsCountryOptionsUyStandard"]
    """
    Options for the standard registration.
    """
    type: Literal["standard"]
    """
    Type of registration to be created in `country`.
    """


class RegistrationCreateParamsCountryOptionsUyStandard(TypedDict):
    place_of_supply_scheme: NotRequired[Literal["inbound_goods", "standard"]]
    """
    Place of supply scheme used in an standard registration.
    """


class RegistrationCreateParamsCountryOptionsUz(TypedDict):
    type: Literal["simplified"]
    """
    Type of registration to be created in `country`.
    """


class RegistrationCreateParamsCountryOptionsVn(TypedDict):
    type: Literal["simplified"]
    """
    Type of registration to be created in `country`.
    """


class RegistrationCreateParamsCountryOptionsZa(TypedDict):
    standard: NotRequired["RegistrationCreateParamsCountryOptionsZaStandard"]
    """
    Options for the standard registration.
    """
    type: Literal["standard"]
    """
    Type of registration to be created in `country`.
    """


class RegistrationCreateParamsCountryOptionsZaStandard(TypedDict):
    place_of_supply_scheme: NotRequired[Literal["inbound_goods", "standard"]]
    """
    Place of supply scheme used in an standard registration.
    """


class RegistrationCreateParamsCountryOptionsZm(TypedDict):
    type: Literal["simplified"]
    """
    Type of registration to be created in `country`.
    """


class RegistrationCreateParamsCountryOptionsZw(TypedDict):
    standard: NotRequired["RegistrationCreateParamsCountryOptionsZwStandard"]
    """
    Options for the standard registration.
    """
    type: Literal["standard"]
    """
    Type of registration to be created in `country`.
    """


class RegistrationCreateParamsCountryOptionsZwStandard(TypedDict):
    place_of_supply_scheme: NotRequired[Literal["inbound_goods", "standard"]]
    """
    Place of supply scheme used in an standard registration.
    """



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe._stripe_service import StripeService
from stripe._util import sanitize_id
from typing import Optional, cast
from importlib import import_module
from typing_extensions import TYPE_CHECKING

if TYPE_CHECKING:
    from stripe._request_options import RequestOptions
    from stripe.params.v2.billing._intent_cancel_params import (
        IntentCancelParams,
    )
    from stripe.params.v2.billing._intent_commit_params import (
        IntentCommitParams,
    )
    from stripe.params.v2.billing._intent_create_params import (
        IntentCreateParams,
    )
    from stripe.params.v2.billing._intent_list_params import IntentListParams
    from stripe.params.v2.billing._intent_release_reservation_params import (
        IntentReleaseReservationParams,
    )
    from stripe.params.v2.billing._intent_reserve_params import (
        IntentReserveParams,
    )
    from stripe.params.v2.billing._intent_retrieve_params import (
        IntentRetrieveParams,
    )
    from stripe.v2._list_object import ListObject
    from stripe.v2.billing._intent import Intent
    from stripe.v2.billing.intents._action_service import ActionService

_subservices = {
    "actions": ["stripe.v2.billing.intents._action_service", "ActionService"],
}


class IntentService(StripeService):
    actions: "ActionService"

    def __init__(self, requestor):
        super().__init__(requestor)

    def __getattr__(self, name):
        try:
            import_from, service = _subservices[name]
            service_class = getattr(
                import_module(import_from),
                service,
            )
            setattr(
                self,
                name,
                service_class(self._requestor),
            )
            return getattr(self, name)
        except KeyError:
            raise AttributeError()

    def list(
        self,
        params: Optional["IntentListParams"] = None,
        options: Optional["RequestOptions"] = None,
    ) -> "ListObject[Intent]":
        """
        List Billing Intents.
        """
        return cast(
            "ListObject[Intent]",
            self._request(
                "get",
                "/v2/billing/intents",
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def list_async(
        self,
        params: Optional["IntentListParams"] = None,
        options: Optional["RequestOptions"] = None,
    ) -> "ListObject[Intent]":
        """
        List Billing Intents.
        """
        return cast(
            "ListObject[Intent]",
            await self._request_async(
                "get",
                "/v2/billing/intents",
                base_address="api",
                params=params,
                options=options,
            ),
        )

    def create(
        self,
        params: "IntentCreateParams",
        options: Optional["RequestOptions"] = None,
    ) -> "Intent":
        """
        Create a Billing Intent.
        """
        return cast(
            "Intent",
            self._request(
                "post",
                "/v2/billing/intents",
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def create_async(
        self,
        params: "IntentCreateParams",
        options: Optional["RequestOptions"] = None,
    ) -> "Intent":
        """
        Create a Billing Intent.
        """
        return cast(
            "Intent",
            await self._request_async(
                "post",
                "/v2/billing/intents",
                base_address="api",
                params=params,
                options=options,
            ),
        )

    def retrieve(
        self,
        id: str,
        params: Optional["IntentRetrieveParams"] = None,
        options: Optional["RequestOptions"] = None,
    ) -> "Intent":
        """
        Retrieve a Billing Intent.
        """
        return cast(
            "Intent",
            self._request(
                "get",
                "/v2/billing/intents/{id}".format(id=sanitize_id(id)),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def retrieve_async(
        self,
        id: str,
        params: Optional["IntentRetrieveParams"] = None,
        options: Optional["RequestOptions"] = None,
    ) -> "Intent":
        """
        Retrieve a Billing Intent.
        """
        return cast(
            "Intent",
            await self._request_async(
                "get",
                "/v2/billing/intents/{id}".format(id=sanitize_id(id)),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    def cancel(
        self,
        id: str,
        params: Optional["IntentCancelParams"] = None,
        options: Optional["RequestOptions"] = None,
    ) -> "Intent":
        """
        Cancel a Billing Intent.
        """
        return cast(
            "Intent",
            self._request(
                "post",
                "/v2/billing/intents/{id}/cancel".format(id=sanitize_id(id)),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def cancel_async(
        self,
        id: str,
        params: Optional["IntentCancelParams"] = None,
        options: Optional["RequestOptions"] = None,
    ) -> "Intent":
        """
        Cancel a Billing Intent.
        """
        return cast(
            "Intent",
            await self._request_async(
                "post",
                "/v2/billing/intents/{id}/cancel".format(id=sanitize_id(id)),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    def commit(
        self,
        id: str,
        params: Optional["IntentCommitParams"] = None,
        options: Optional["RequestOptions"] = None,
    ) -> "Intent":
        """
        Commit a Billing Intent.
        """
        return cast(
            "Intent",
            self._request(
                "post",
                "/v2/billing/intents/{id}/commit".format(id=sanitize_id(id)),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def commit_async(
        self,
        id: str,
        params: Optional["IntentCommitParams"] = None,
        options: Optional["RequestOptions"] = None,
    ) -> "Intent":
        """
        Commit a Billing Intent.
        """
        return cast(
            "Intent",
            await self._request_async(
                "post",
                "/v2/billing/intents/{id}/commit".format(id=sanitize_id(id)),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    def release_reservation(
        self,
        id: str,
        params: Optional["IntentReleaseReservationParams"] = None,
        options: Optional["RequestOptions"] = None,
    ) -> "Intent":
        """
        Release a Billing Intent.
        """
        return cast(
            "Intent",
            self._request(
                "post",
                "/v2/billing/intents/{id}/release_reservation".format(
                    id=sanitize_id(id),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def release_reservation_async(
        self,
        id: str,
        params: Optional["IntentReleaseReservationParams"] = None,
        options: Optional["RequestOptions"] = None,
    ) -> "Intent":
        """
        Release a Billing Intent.
        """
        return cast(
            "Intent",
            await self._request_async(
                "post",
                "/v2/billing/intents/{id}/release_reservation".format(
                    id=sanitize_id(id),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    def reserve(
        self,
        id: str,
        params: Optional["IntentReserveParams"] = None,
        options: Optional["RequestOptions"] = None,
    ) -> "Intent":
        """
        Reserve a Billing Intent.
        """
        return cast(
            "Intent",
            self._request(
                "post",
                "/v2/billing/intents/{id}/reserve".format(id=sanitize_id(id)),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def reserve_async(
        self,
        id: str,
        params: Optional["IntentReserveParams"] = None,
        options: Optional["RequestOptions"] = None,
    ) -> "Intent":
        """
        Reserve a Billing Intent.
        """
        return cast(
            "Intent",
            await self._request_async(
                "post",
                "/v2/billing/intents/{id}/reserve".format(id=sanitize_id(id)),
                base_address="api",
                params=params,
                options=options,
            ),
        )



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from typing import Dict, List
from typing_extensions import Literal, NotRequired, TypedDict


class EventDestinationCreateParams(TypedDict):
    description: NotRequired[str]
    """
    An optional description of what the event destination is used for.
    """
    enabled_events: List[str]
    """
    The list of events to enable for this endpoint.
    """
    event_payload: Literal["snapshot", "thin"]
    """
    Payload type of events being subscribed to.
    """
    events_from: NotRequired[List[Literal["other_accounts", "self"]]]
    """
    Where events should be routed from.
    """
    include: NotRequired[
        List[
            Literal["webhook_endpoint.signing_secret", "webhook_endpoint.url"]
        ]
    ]
    """
    Additional fields to include in the response.
    """
    metadata: NotRequired[Dict[str, str]]
    """
    Metadata.
    """
    name: str
    """
    Event destination name.
    """
    snapshot_api_version: NotRequired[str]
    """
    If using the snapshot event payload, the API version events are rendered as.
    """
    type: Literal["amazon_eventbridge", "webhook_endpoint"]
    """
    Event destination type.
    """
    amazon_eventbridge: NotRequired[
        "EventDestinationCreateParamsAmazonEventbridge"
    ]
    """
    Amazon EventBridge configuration.
    """
    webhook_endpoint: NotRequired[
        "EventDestinationCreateParamsWebhookEndpoint"
    ]
    """
    Webhook endpoint configuration.
    """


class EventDestinationCreateParamsAmazonEventbridge(TypedDict):
    aws_account_id: str
    """
    The AWS account ID.
    """
    aws_region: str
    """
    The region of the AWS event source.
    """


class EventDestinationCreateParamsWebhookEndpoint(TypedDict):
    url: str
    """
    The URL of the webhook endpoint.
    """



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe._request_options import RequestOptions
from typing import List
from typing_extensions import Literal, NotRequired, TypedDict


class AuthorizationCreateParams(RequestOptions):
    amount: NotRequired[int]
    """
    The total amount to attempt to authorize. This amount is in the provided currency, or defaults to the card's currency, and in the [smallest currency unit](https://stripe.com/docs/currencies#zero-decimal).
    """
    amount_details: NotRequired["AuthorizationCreateParamsAmountDetails"]
    """
    Detailed breakdown of amount components. These amounts are denominated in `currency` and in the [smallest currency unit](https://stripe.com/docs/currencies#zero-decimal).
    """
    authorization_method: NotRequired[
        Literal["chip", "contactless", "keyed_in", "online", "swipe"]
    ]
    """
    How the card details were provided. Defaults to online.
    """
    card: str
    """
    Card associated with this authorization.
    """
    currency: NotRequired[str]
    """
    The currency of the authorization. If not provided, defaults to the currency of the card. Three-letter [ISO currency code](https://www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](https://stripe.com/docs/currencies).
    """
    expand: NotRequired[List[str]]
    """
    Specifies which fields in the response should be expanded.
    """
    fleet: NotRequired["AuthorizationCreateParamsFleet"]
    """
    Fleet-specific information for authorizations using Fleet cards.
    """
    fraud_disputability_likelihood: NotRequired[
        Literal["neutral", "unknown", "very_likely", "very_unlikely"]
    ]
    """
    Probability that this transaction can be disputed in the event of fraud. Assessed by comparing the characteristics of the authorization to card network rules.
    """
    fuel: NotRequired["AuthorizationCreateParamsFuel"]
    """
    Information about fuel that was purchased with this transaction.
    """
    is_amount_controllable: NotRequired[bool]
    """
    If set `true`, you may provide [amount](https://stripe.com/docs/api/issuing/authorizations/approve#approve_issuing_authorization-amount) to control how much to hold for the authorization.
    """
    merchant_amount: NotRequired[int]
    """
    The total amount to attempt to authorize. This amount is in the provided merchant currency, and in the [smallest currency unit](https://stripe.com/docs/currencies#zero-decimal).
    """
    merchant_currency: NotRequired[str]
    """
    The currency of the authorization. If not provided, defaults to the currency of the card. Three-letter [ISO currency code](https://www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](https://stripe.com/docs/currencies).
    """
    merchant_data: NotRequired["AuthorizationCreateParamsMerchantData"]
    """
    Details about the seller (grocery store, e-commerce website, etc.) where the card authorization happened.
    """
    network_data: NotRequired["AuthorizationCreateParamsNetworkData"]
    """
    Details about the authorization, such as identifiers, set by the card network.
    """
    risk_assessment: NotRequired["AuthorizationCreateParamsRiskAssessment"]
    """
    Stripe's assessment of the fraud risk for this authorization.
    """
    verification_data: NotRequired["AuthorizationCreateParamsVerificationData"]
    """
    Verifications that Stripe performed on information that the cardholder provided to the merchant.
    """
    wallet: NotRequired[Literal["apple_pay", "google_pay", "samsung_pay"]]
    """
    The digital wallet used for this transaction. One of `apple_pay`, `google_pay`, or `samsung_pay`. Will populate as `null` when no digital wallet was utilized.
    """


class AuthorizationCreateParamsAmountDetails(TypedDict):
    atm_fee: NotRequired[int]
    """
    The ATM withdrawal fee.
    """
    cashback_amount: NotRequired[int]
    """
    The amount of cash requested by the cardholder.
    """


class AuthorizationCreateParamsFleet(TypedDict):
    cardholder_prompt_data: NotRequired[
        "AuthorizationCreateParamsFleetCardholderPromptData"
    ]
    """
    Answers to prompts presented to the cardholder at the point of sale. Prompted fields vary depending on the configuration of your physical fleet cards. Typical points of sale support only numeric entry.
    """
    purchase_type: NotRequired[
        Literal[
            "fuel_and_non_fuel_purchase", "fuel_purchase", "non_fuel_purchase"
        ]
    ]
    """
    The type of purchase. One of `fuel_purchase`, `non_fuel_purchase`, or `fuel_and_non_fuel_purchase`.
    """
    reported_breakdown: NotRequired[
        "AuthorizationCreateParamsFleetReportedBreakdown"
    ]
    """
    More information about the total amount. This information is not guaranteed to be accurate as some merchants may provide unreliable data.
    """
    service_type: NotRequired[
        Literal["full_service", "non_fuel_transaction", "self_service"]
    ]
    """
    The type of fuel service. One of `non_fuel_transaction`, `full_service`, or `self_service`.
    """


class AuthorizationCreateParamsFleetCardholderPromptData(TypedDict):
    driver_id: NotRequired[str]
    """
    Driver ID.
    """
    odometer: NotRequired[int]
    """
    Odometer reading.
    """
    unspecified_id: NotRequired[str]
    """
    An alphanumeric ID. This field is used when a vehicle ID, driver ID, or generic ID is entered by the cardholder, but the merchant or card network did not specify the prompt type.
    """
    user_id: NotRequired[str]
    """
    User ID.
    """
    vehicle_number: NotRequired[str]
    """
    Vehicle number.
    """


class AuthorizationCreateParamsFleetReportedBreakdown(TypedDict):
    fuel: NotRequired["AuthorizationCreateParamsFleetReportedBreakdownFuel"]
    """
    Breakdown of fuel portion of the purchase.
    """
    non_fuel: NotRequired[
        "AuthorizationCreateParamsFleetReportedBreakdownNonFuel"
    ]
    """
    Breakdown of non-fuel portion of the purchase.
    """
    tax: NotRequired["AuthorizationCreateParamsFleetReportedBreakdownTax"]
    """
    Information about tax included in this transaction.
    """


class AuthorizationCreateParamsFleetReportedBreakdownFuel(TypedDict):
    gross_amount_decimal: NotRequired[str]
    """
    Gross fuel amount that should equal Fuel Volume multipled by Fuel Unit Cost, inclusive of taxes.
    """


class AuthorizationCreateParamsFleetReportedBreakdownNonFuel(TypedDict):
    gross_amount_decimal: NotRequired[str]
    """
    Gross non-fuel amount that should equal the sum of the line items, inclusive of taxes.
    """


class AuthorizationCreateParamsFleetReportedBreakdownTax(TypedDict):
    local_amount_decimal: NotRequired[str]
    """
    Amount of state or provincial Sales Tax included in the transaction amount. Null if not reported by merchant or not subject to tax.
    """
    national_amount_decimal: NotRequired[str]
    """
    Amount of national Sales Tax or VAT included in the transaction amount. Null if not reported by merchant or not subject to tax.
    """


class AuthorizationCreateParamsFuel(TypedDict):
    industry_product_code: NotRequired[str]
    """
    [Conexxus Payment System Product Code](https://www.conexxus.org/conexxus-payment-system-product-codes) identifying the primary fuel product purchased.
    """
    quantity_decimal: NotRequired[str]
    """
    The quantity of `unit`s of fuel that was dispensed, represented as a decimal string with at most 12 decimal places.
    """
    type: NotRequired[
        Literal[
            "diesel",
            "other",
            "unleaded_plus",
            "unleaded_regular",
            "unleaded_super",
        ]
    ]
    """
    The type of fuel that was purchased. One of `diesel`, `unleaded_plus`, `unleaded_regular`, `unleaded_super`, or `other`.
    """
    unit: NotRequired[
        Literal[
            "charging_minute",
            "imperial_gallon",
            "kilogram",
            "kilowatt_hour",
            "liter",
            "other",
            "pound",
            "us_gallon",
        ]
    ]
    """
    The units for `quantity_decimal`. One of `charging_minute`, `imperial_gallon`, `kilogram`, `kilowatt_hour`, `liter`, `pound`, `us_gallon`, or `other`.
    """
    unit_cost_decimal: NotRequired[str]
    """
    The cost in cents per each unit of fuel, represented as a decimal string with at most 12 decimal places.
    """


class AuthorizationCreateParamsMerchantData(TypedDict):
    category: NotRequired[
        Literal[
            "ac_refrigeration_repair",
            "accounting_bookkeeping_services",
            "advertising_services",
            "agricultural_cooperative",
            "airlines_air_carriers",
            "airports_flying_fields",
            "ambulance_services",
            "amusement_parks_carnivals",
            "antique_reproductions",
            "antique_shops",
            "aquariums",
            "architectural_surveying_services",
            "art_dealers_and_galleries",
            "artists_supply_and_craft_shops",
            "auto_and_home_supply_stores",
            "auto_body_repair_shops",
            "auto_paint_shops",
            "auto_service_shops",
            "automated_cash_disburse",
            "automated_fuel_dispensers",
            "automobile_associations",
            "automotive_parts_and_accessories_stores",
            "automotive_tire_stores",
            "bail_and_bond_payments",
            "bakeries",
            "bands_orchestras",
            "barber_and_beauty_shops",
            "betting_casino_gambling",
            "bicycle_shops",
            "billiard_pool_establishments",
            "boat_dealers",
            "boat_rentals_and_leases",
            "book_stores",
            "books_periodicals_and_newspapers",
            "bowling_alleys",
            "bus_lines",
            "business_secretarial_schools",
            "buying_shopping_services",
            "cable_satellite_and_other_pay_television_and_radio",
            "camera_and_photographic_supply_stores",
            "candy_nut_and_confectionery_stores",
            "car_and_truck_dealers_new_used",
            "car_and_truck_dealers_used_only",
            "car_rental_agencies",
            "car_washes",
            "carpentry_services",
            "carpet_upholstery_cleaning",
            "caterers",
            "charitable_and_social_service_organizations_fundraising",
            "chemicals_and_allied_products",
            "child_care_services",
            "childrens_and_infants_wear_stores",
            "chiropodists_podiatrists",
            "chiropractors",
            "cigar_stores_and_stands",
            "civic_social_fraternal_associations",
            "cleaning_and_maintenance",
            "clothing_rental",
            "colleges_universities",
            "commercial_equipment",
            "commercial_footwear",
            "commercial_photography_art_and_graphics",
            "commuter_transport_and_ferries",
            "computer_network_services",
            "computer_programming",
            "computer_repair",
            "computer_software_stores",
            "computers_peripherals_and_software",
            "concrete_work_services",
            "construction_materials",
            "consulting_public_relations",
            "correspondence_schools",
            "cosmetic_stores",
            "counseling_services",
            "country_clubs",
            "courier_services",
            "court_costs",
            "credit_reporting_agencies",
            "cruise_lines",
            "dairy_products_stores",
            "dance_hall_studios_schools",
            "dating_escort_services",
            "dentists_orthodontists",
            "department_stores",
            "detective_agencies",
            "digital_goods_applications",
            "digital_goods_games",
            "digital_goods_large_volume",
            "digital_goods_media",
            "direct_marketing_catalog_merchant",
            "direct_marketing_combination_catalog_and_retail_merchant",
            "direct_marketing_inbound_telemarketing",
            "direct_marketing_insurance_services",
            "direct_marketing_other",
            "direct_marketing_outbound_telemarketing",
            "direct_marketing_subscription",
            "direct_marketing_travel",
            "discount_stores",
            "doctors",
            "door_to_door_sales",
            "drapery_window_covering_and_upholstery_stores",
            "drinking_places",
            "drug_stores_and_pharmacies",
            "drugs_drug_proprietaries_and_druggist_sundries",
            "dry_cleaners",
            "durable_goods",
            "duty_free_stores",
            "eating_places_restaurants",
            "educational_services",
            "electric_razor_stores",
            "electric_vehicle_charging",
            "electrical_parts_and_equipment",
            "electrical_services",
            "electronics_repair_shops",
            "electronics_stores",
            "elementary_secondary_schools",
            "emergency_services_gcas_visa_use_only",
            "employment_temp_agencies",
            "equipment_rental",
            "exterminating_services",
            "family_clothing_stores",
            "fast_food_restaurants",
            "financial_institutions",
            "fines_government_administrative_entities",
            "fireplace_fireplace_screens_and_accessories_stores",
            "floor_covering_stores",
            "florists",
            "florists_supplies_nursery_stock_and_flowers",
            "freezer_and_locker_meat_provisioners",
            "fuel_dealers_non_automotive",
            "funeral_services_crematories",
            "furniture_home_furnishings_and_equipment_stores_except_appliances",
            "furniture_repair_refinishing",
            "furriers_and_fur_shops",
            "general_services",
            "gift_card_novelty_and_souvenir_shops",
            "glass_paint_and_wallpaper_stores",
            "glassware_crystal_stores",
            "golf_courses_public",
            "government_licensed_horse_dog_racing_us_region_only",
            "government_licensed_online_casions_online_gambling_us_region_only",
            "government_owned_lotteries_non_us_region",
            "government_owned_lotteries_us_region_only",
            "government_services",
            "grocery_stores_supermarkets",
            "hardware_equipment_and_supplies",
            "hardware_stores",
            "health_and_beauty_spas",
            "hearing_aids_sales_and_supplies",
            "heating_plumbing_a_c",
            "hobby_toy_and_game_shops",
            "home_supply_warehouse_stores",
            "hospitals",
            "hotels_motels_and_resorts",
            "household_appliance_stores",
            "industrial_supplies",
            "information_retrieval_services",
            "insurance_default",
            "insurance_underwriting_premiums",
            "intra_company_purchases",
            "jewelry_stores_watches_clocks_and_silverware_stores",
            "landscaping_services",
            "laundries",
            "laundry_cleaning_services",
            "legal_services_attorneys",
            "luggage_and_leather_goods_stores",
            "lumber_building_materials_stores",
            "manual_cash_disburse",
            "marinas_service_and_supplies",
            "marketplaces",
            "masonry_stonework_and_plaster",
            "massage_parlors",
            "medical_and_dental_labs",
            "medical_dental_ophthalmic_and_hospital_equipment_and_supplies",
            "medical_services",
            "membership_organizations",
            "mens_and_boys_clothing_and_accessories_stores",
            "mens_womens_clothing_stores",
            "metal_service_centers",
            "miscellaneous_apparel_and_accessory_shops",
            "miscellaneous_auto_dealers",
            "miscellaneous_business_services",
            "miscellaneous_food_stores",
            "miscellaneous_general_merchandise",
            "miscellaneous_general_services",
            "miscellaneous_home_furnishing_specialty_stores",
            "miscellaneous_publishing_and_printing",
            "miscellaneous_recreation_services",
            "miscellaneous_repair_shops",
            "miscellaneous_specialty_retail",
            "mobile_home_dealers",
            "motion_picture_theaters",
            "motor_freight_carriers_and_trucking",
            "motor_homes_dealers",
            "motor_vehicle_supplies_and_new_parts",
            "motorcycle_shops_and_dealers",
            "motorcycle_shops_dealers",
            "music_stores_musical_instruments_pianos_and_sheet_music",
            "news_dealers_and_newsstands",
            "non_fi_money_orders",
            "non_fi_stored_value_card_purchase_load",
            "nondurable_goods",
            "nurseries_lawn_and_garden_supply_stores",
            "nursing_personal_care",
            "office_and_commercial_furniture",
            "opticians_eyeglasses",
            "optometrists_ophthalmologist",
            "orthopedic_goods_prosthetic_devices",
            "osteopaths",
            "package_stores_beer_wine_and_liquor",
            "paints_varnishes_and_supplies",
            "parking_lots_garages",
            "passenger_railways",
            "pawn_shops",
            "pet_shops_pet_food_and_supplies",
            "petroleum_and_petroleum_products",
            "photo_developing",
            "photographic_photocopy_microfilm_equipment_and_supplies",
            "photographic_studios",
            "picture_video_production",
            "piece_goods_notions_and_other_dry_goods",
            "plumbing_heating_equipment_and_supplies",
            "political_organizations",
            "postal_services_government_only",
            "precious_stones_and_metals_watches_and_jewelry",
            "professional_services",
            "public_warehousing_and_storage",
            "quick_copy_repro_and_blueprint",
            "railroads",
            "real_estate_agents_and_managers_rentals",
            "record_stores",
            "recreational_vehicle_rentals",
            "religious_goods_stores",
            "religious_organizations",
            "roofing_siding_sheet_metal",
            "secretarial_support_services",
            "security_brokers_dealers",
            "service_stations",
            "sewing_needlework_fabric_and_piece_goods_stores",
            "shoe_repair_hat_cleaning",
            "shoe_stores",
            "small_appliance_repair",
            "snowmobile_dealers",
            "special_trade_services",
            "specialty_cleaning",
            "sporting_goods_stores",
            "sporting_recreation_camps",
            "sports_and_riding_apparel_stores",
            "sports_clubs_fields",
            "stamp_and_coin_stores",
            "stationary_office_supplies_printing_and_writing_paper",
            "stationery_stores_office_and_school_supply_stores",
            "swimming_pools_sales",
            "t_ui_travel_germany",
            "tailors_alterations",
            "tax_payments_government_agencies",
            "tax_preparation_services",
            "taxicabs_limousines",
            "telecommunication_equipment_and_telephone_sales",
            "telecommunication_services",
            "telegraph_services",
            "tent_and_awning_shops",
            "testing_laboratories",
            "theatrical_ticket_agencies",
            "timeshares",
            "tire_retreading_and_repair",
            "tolls_bridge_fees",
            "tourist_attractions_and_exhibits",
            "towing_services",
            "trailer_parks_campgrounds",
            "transportation_services",
            "travel_agencies_tour_operators",
            "truck_stop_iteration",
            "truck_utility_trailer_rentals",
            "typesetting_plate_making_and_related_services",
            "typewriter_stores",
            "u_s_federal_government_agencies_or_departments",
            "uniforms_commercial_clothing",
            "used_merchandise_and_secondhand_stores",
            "utilities",
            "variety_stores",
            "veterinary_services",
            "video_amusement_game_supplies",
            "video_game_arcades",
            "video_tape_rental_stores",
            "vocational_trade_schools",
            "watch_jewelry_repair",
            "welding_repair",
            "wholesale_clubs",
            "wig_and_toupee_stores",
            "wires_money_orders",
            "womens_accessory_and_specialty_shops",
            "womens_ready_to_wear_stores",
            "wrecking_and_salvage_yards",
        ]
    ]
    """
    A categorization of the seller's type of business. See our [merchant categories guide](https://stripe.com/docs/issuing/merchant-categories) for a list of possible values.
    """
    city: NotRequired[str]
    """
    City where the seller is located
    """
    country: NotRequired[str]
    """
    Country where the seller is located
    """
    name: NotRequired[str]
    """
    Name of the seller
    """
    network_id: NotRequired[str]
    """
    Identifier assigned to the seller by the card network. Different card networks may assign different network_id fields to the same merchant.
    """
    postal_code: NotRequired[str]
    """
    Postal code where the seller is located
    """
    state: NotRequired[str]
    """
    State where the seller is located
    """
    terminal_id: NotRequired[str]
    """
    An ID assigned by the seller to the location of the sale.
    """
    url: NotRequired[str]
    """
    URL provided by the merchant on a 3DS request
    """


class AuthorizationCreateParamsNetworkData(TypedDict):
    acquiring_institution_id: NotRequired[str]
    """
    Identifier assigned to the acquirer by the card network.
    """


class AuthorizationCreateParamsRiskAssessment(TypedDict):
    card_testing_risk: NotRequired[
        "AuthorizationCreateParamsRiskAssessmentCardTestingRisk"
    ]
    """
    Stripe's assessment of this authorization's likelihood of being card testing activity.
    """
    fraud_risk: NotRequired["AuthorizationCreateParamsRiskAssessmentFraudRisk"]
    """
    Stripe's assessment of this authorization's likelihood to be fraudulent.
    """
    merchant_dispute_risk: NotRequired[
        "AuthorizationCreateParamsRiskAssessmentMerchantDisputeRisk"
    ]
    """
    The dispute risk of the merchant (the seller on a purchase) on an authorization based on all Stripe Issuing activity.
    """


class AuthorizationCreateParamsRiskAssessmentCardTestingRisk(TypedDict):
    invalid_account_number_decline_rate_past_hour: NotRequired[int]
    """
    The % of declines due to a card number not existing in the past hour, taking place at the same merchant. Higher rates correspond to a greater probability of card testing activity, meaning bad actors may be attempting different card number combinations to guess a correct one. Takes on values between 0 and 100.
    """
    invalid_credentials_decline_rate_past_hour: NotRequired[int]
    """
    The % of declines due to incorrect verification data (like CVV or expiry) in the past hour, taking place at the same merchant. Higher rates correspond to a greater probability of bad actors attempting to utilize valid card credentials at merchants with verification requirements. Takes on values between 0 and 100.
    """
    risk_level: Literal[
        "elevated", "highest", "low", "normal", "not_assessed", "unknown"
    ]
    """
    The likelihood that this authorization is associated with card testing activity. This is assessed by evaluating decline activity over the last hour.
    """


class AuthorizationCreateParamsRiskAssessmentFraudRisk(TypedDict):
    level: Literal[
        "elevated", "highest", "low", "normal", "not_assessed", "unknown"
    ]
    """
    Stripe's assessment of the likelihood of fraud on an authorization.
    """
    score: NotRequired[float]
    """
    Stripe's numerical model score assessing the likelihood of fraudulent activity. A higher score means a higher likelihood of fraudulent activity, and anything above 25 is considered high risk.
    """


class AuthorizationCreateParamsRiskAssessmentMerchantDisputeRisk(TypedDict):
    dispute_rate: NotRequired[int]
    """
    The dispute rate observed across all Stripe Issuing authorizations for this merchant. For example, a value of 50 means 50% of authorizations from this merchant on Stripe Issuing have resulted in a dispute. Higher values mean a higher likelihood the authorization is disputed. Takes on values between 0 and 100.
    """
    risk_level: Literal[
        "elevated", "highest", "low", "normal", "not_assessed", "unknown"
    ]
    """
    The likelihood that authorizations from this merchant will result in a dispute based on their history on Stripe Issuing.
    """


class AuthorizationCreateParamsVerificationData(TypedDict):
    address_line1_check: NotRequired[
        Literal["match", "mismatch", "not_provided"]
    ]
    """
    Whether the cardholder provided an address first line and if it matched the cardholder's `billing.address.line1`.
    """
    address_postal_code_check: NotRequired[
        Literal["match", "mismatch", "not_provided"]
    ]
    """
    Whether the cardholder provided a postal code and if it matched the cardholder's `billing.address.postal_code`.
    """
    authentication_exemption: NotRequired[
        "AuthorizationCreateParamsVerificationDataAuthenticationExemption"
    ]
    """
    The exemption applied to this authorization.
    """
    cvc_check: NotRequired[Literal["match", "mismatch", "not_provided"]]
    """
    Whether the cardholder provided a CVC and if it matched Stripe's record.
    """
    expiry_check: NotRequired[Literal["match", "mismatch", "not_provided"]]
    """
    Whether the cardholder provided an expiry date and if it matched Stripe's record.
    """
    three_d_secure: NotRequired[
        "AuthorizationCreateParamsVerificationDataThreeDSecure"
    ]
    """
    3D Secure details.
    """


class AuthorizationCreateParamsVerificationDataAuthenticationExemption(
    TypedDict,
):
    claimed_by: Literal["acquirer", "issuer"]
    """
    The entity that requested the exemption, either the acquiring merchant or the Issuing user.
    """
    type: Literal[
        "low_value_transaction", "transaction_risk_analysis", "unknown"
    ]
    """
    The specific exemption claimed for this authorization.
    """


class AuthorizationCreateParamsVerificationDataThreeDSecure(TypedDict):
    result: Literal[
        "attempt_acknowledged", "authenticated", "failed", "required"
    ]
    """
    The outcome of the 3D Secure authentication request.
    """



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe._expandable_field import ExpandableField
from stripe._list_object import ListObject
from stripe._listable_api_resource import ListableAPIResource
from typing import ClassVar, Optional
from typing_extensions import Literal, Unpack, TYPE_CHECKING

if TYPE_CHECKING:
    from stripe._balance_transaction import BalanceTransaction
    from stripe.params.issuing._fraud_liability_debit_list_params import (
        FraudLiabilityDebitListParams,
    )
    from stripe.params.issuing._fraud_liability_debit_retrieve_params import (
        FraudLiabilityDebitRetrieveParams,
    )


class FraudLiabilityDebit(ListableAPIResource["FraudLiabilityDebit"]):
    """
    A fraud liability debit occurs when Stripe debits a platform's account for fraud losses on Issuing transactions.
    """

    OBJECT_NAME: ClassVar[Literal["issuing.fraud_liability_debit"]] = (
        "issuing.fraud_liability_debit"
    )
    amount: int
    """
    Debited amount. This is equal to the disputed amount and is given in the card's currency and in the smallest currency unit.
    """
    balance_transaction: Optional[ExpandableField["BalanceTransaction"]]
    """
    ID of the [balance transaction](https://stripe.com/docs/api/balance_transactions) associated with this debit.
    """
    created: int
    """
    Time at which the object was created. Measured in seconds since the Unix epoch.
    """
    currency: str
    """
    The currency of the debit. Three-letter [ISO currency code](https://www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](https://stripe.com/docs/currencies).
    """
    dispute: str
    """
    The ID of the linked dispute.
    """
    id: str
    """
    Unique identifier for the object.
    """
    livemode: bool
    """
    Has the value `true` if the object exists in live mode or the value `false` if the object exists in test mode.
    """
    object: Literal["issuing.fraud_liability_debit"]
    """
    String representing the object's type. Objects of the same type share the same value.
    """

    @classmethod
    def list(
        cls, **params: Unpack["FraudLiabilityDebitListParams"]
    ) -> ListObject["FraudLiabilityDebit"]:
        """
        Returns a list of Issuing FraudLiabilityDebit objects. The objects are sorted in descending order by creation date, with the most recently created object appearing first.
        """
        result = cls._static_request(
            "get",
            cls.class_url(),
            params=params,
        )
        if not isinstance(result, ListObject):
            raise TypeError(
                "Expected list object from API, got %s"
                % (type(result).__name__)
            )

        return result

    @classmethod
    async def list_async(
        cls, **params: Unpack["FraudLiabilityDebitListParams"]
    ) -> ListObject["FraudLiabilityDebit"]:
        """
        Returns a list of Issuing FraudLiabilityDebit objects. The objects are sorted in descending order by creation date, with the most recently created object appearing first.
        """
        result = await cls._static_request_async(
            "get",
            cls.class_url(),
            params=params,
        )
        if not isinstance(result, ListObject):
            raise TypeError(
                "Expected list object from API, got %s"
                % (type(result).__name__)
            )

        return result

    @classmethod
    def retrieve(
        cls, id: str, **params: Unpack["FraudLiabilityDebitRetrieveParams"]
    ) -> "FraudLiabilityDebit":
        """
        Retrieves an Issuing FraudLiabilityDebit object.
        """
        instance = cls(id, **params)
        instance.refresh()
        return instance

    @classmethod
    async def retrieve_async(
        cls, id: str, **params: Unpack["FraudLiabilityDebitRetrieveParams"]
    ) -> "FraudLiabilityDebit":
        """
        Retrieves an Issuing FraudLiabilityDebit object.
        """
        instance = cls(id, **params)
        await instance.refresh_async()
        return instance
